<?php

namespace Litecms\Email\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Email\Interfaces\EmailsRepositoryInterface;

class EmailsPublicController extends BaseController
{
    // use EmailsWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Emails\Interfaces\EmailsRepositoryInterface $emails
     *
     * @return type
     */
    public function __construct(EmailsRepositoryInterface $emails)
    {
        $this->repository = $emails;
        parent::__construct();
    }

    /**
     * Show emails's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $emails = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('email::emails.names'))
            ->view('email::public.emails.index')
            ->data(compact('emails'))
            ->output();
    }


    /**
     * Show emails.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $emails = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($emails->name . trans('email::emails.name'))
            ->view('email::public.emails.show')
            ->data(compact('emails'))
            ->output();
    }

}
